Recherche de site Web

Guide du débutant pour utiliser la commande dpkg sous Linux


Le dpkg est un gestionnaire de paquets de niveau intermédiaire qui vous permet d'installer, de supprimer et de configurer des paquets logiciels sur votre système Linux. Dans ce tutoriel, nous vous guiderons à travers les bases de l'utilisation de la commande dpkg dans Debian, Ubuntu et ses dérivés.

Qu'est-ce que dpkg dans Linux ?

dpkg signifie "Debian Package" et est l'outil sous-jacent utilisé par les distributions Linux basées sur Debian comme Ubuntu. C'est un utilitaire en ligne de commande qui vous permet de gérer des paquets .deb individuels sur votre système.

Bien que dpkg soit puissant, il est considéré comme un outil de niveau moyen, ce qui signifie qu'il ne gère pas automatiquement les dépendances. Pour cela, vous pourriez vouloir utiliser un gestionnaire de paquets de niveau supérieur comme apt.

Syntaxe de base

La syntaxe de base de la commande dpkg est :

dpkg [options] action

Actions courantes:

  • -i, --install <package_file> : Installer le paquet .deb spécifié.
  • -r, --remove <nom_du_paquet> : Supprime le paquet spécifié (mais conserve ses fichiers de configuration).
  • -P, --purger <nom_du_paquet> : Supprime le paquet spécifié et purge ses fichiers de configuration.
  • -l, --list [package_name] : Liste les paquets correspondant au modèle donné. Si aucun modèle n'est fourni, il liste tous les paquets installés.
  • -s, --status <nom_du_paquet> : Affiche des informations détaillées sur l'état du paquet spécifié.
  • -L, --listfiles <nom_du_paquet> : Liste les fichiers installés par le paquet spécifié.
  • -S, --search <filename_pattern> : Rechercher un nom de fichier parmi les paquets installés.
  • -c, --contents <package_file> : Liste le contenu du fichier de package .deb spécifié.

Options importantes:

  • -b, --build <répertoire> : Construire un .deb package à partir du répertoire spécifié.
  • -A, --record-avail <package_file> : Mettre à jour les informations de disponibilité du paquet avec les informations du fichier .deb spécifié.
  • -E, --skip-same-version : Ignorer l'installation d'un paquet si la même version est déjà installée.
  • -G, --refuse-downgrade : Refuser d'installer un paquet si une version plus récente est déjà installée.
  • -R, --recursive : Traiter tous les fichiers qui sont des répertoires, de manière récursive.
  • -V, --verify <nom_du_paquet> : Vérifie l'intégrité du paquet spécifié en contrôlant ses fichiers par rapport aux sommes de contrôle enregistrées.
  • --configure <nom_du_paquet> : Configure un paquet qui a été décompressé mais pas encore configuré.
  • --unpack <package_file> : Décompressez le fichier de paquet .deb spécifié, mais ne le configurez pas.
  • --no-act, --dry-run, --simulate : Effectuer une simulation des actions qui seraient prises, mais ne modifiez pas réellement le système.

Exemples courants de commandes dpkg

Voici quelques-unes des commandes dpkg les plus courantes que nous utiliserons pour les tâches quotidiennes.

1. Installer un paquet

Pour installer un fichier de paquet .deb, utilisez la commande suivante :

dpkg -i package.deb

Exemple :

sudo dpkg -i google-chrome-stable_current_amd64.deb

Cette commande installe le navigateur Google Chrome sur votre système Debian.

2. Supprimer un paquet

Pour supprimer un paquet, utilisez la commande suivante :

dpkg -r package_name

Exemple :

sudo dpkg -r firefox-esr

Cette commande supprime le navigateur Firefox de votre système.

3. Purger un paquet

Si vous voulez supprimer un paquet ainsi que ses fichiers de configuration, utilisez la commande suivante :

dpkg -P package_name

Exemple :

sudo dpkg -P linux-image-5.10.0-11-amd64

Cette commande supprime l'image du noyau Linux spécifiée ainsi que ses fichiers de configuration.

4. Lister les packages installés

Pour lister tous les paquets installés sur votre système, utilisez la commande suivante :

dpkg -l

Vous pouvez également filtrer la liste en utilisant grep :

dpkg -l | grep -i chrome

Cette commande liste tous les paquets installés contenant « chrome » dans leur nom.

Exemple de sortie :

ii  google-chrome-stable                                    129.0.6668.70-1                                      amd64        The web browser from Google

5. Lister les fichiers installés par un paquet

Pour lister tous les fichiers installés par un paquet spécifique, exécutez :

dpkg -L package_name

Exemple:

dpkg -L google-chrome-stable

Exemple de sortie :

/.
/etc
/etc/cron.daily
/opt
/opt/google
/opt/google/chrome
/opt/google/chrome/CHROME_VERSION_EXTRA
/opt/google/chrome/MEIPreload
/opt/google/chrome/MEIPreload/manifest.json
/opt/google/chrome/MEIPreload/preloaded_data.pb
/opt/google/chrome/PrivacySandboxAttestationsPreloaded
/opt/google/chrome/PrivacySandboxAttestationsPreloaded/manifest.json
/opt/google/chrome/PrivacySandboxAttestationsPreloaded/privacy-sandbox-attestations.dat
/opt/google/chrome/WidevineCdm
/opt/google/chrome/WidevineCdm/LICENSE
[...]

6. Découvrez à quel package appartient un fichier

Vous pouvez rechercher un fichier et savoir à quel paquet il appartient en utilisant la commande :

dpkg -S /path/to/file

Par exemple, pour rechercher les paquets auxquels appartient le fichier /bin/uname, utilisez la commande suivante :

dpkg -S /bin/uname

Exemple de sortie :

coreutils: /bin/uname

Comme vous pouvez le voir, le fichier /bin/uname appartient au paquet coreutils.

Lecture similaire : Comment trouver le paquet qui fournit un fichier spécifique sous Linux

7. Afficher l'état du colis

Pour vérifier le statut d'un paquet spécifique, utilisez la commande suivante :

dpkg -s package_name

Exemple :

dpkg -s google-chrome-stable

Cette commande affiche l'état du paquet Google Chrome, y compris s'il est installé, configuré ou non installé.

Package: google-chrome-stable
Status: install ok installed
Priority: optional
Section: web
Installed-Size: 356732
Maintainer: Chrome Linux Team <chromium-dev@chromium.org>
Architecture: amd64
Version: 129.0.6668.70-1
Provides: www-browser
Depends: ca-certificates, fonts-liberation, libasound2 (>= 1.0.17), libatk-bridge2.0-0 (>= 2.5.3), libatk1.0-0 (>= 2.11.90), libatspi2.0-0 (>= 2.9.90), libc6 (>= 2.17), libcairo2 (>= 1.6.0), libcups2 (>= 1.7.0), libcurl3-gnutls | libcurl3-nss | libcurl4 | libcurl3, libdbus-1-3 (>= 1.9.14), libdrm2 (>= 2.4.75), libexpat1 (>= 2.1~beta3), libgbm1 (>= 17.1.0~rc2), libglib2.0-0 (>= 2.39.4), libgtk-3-0 (>= 3.9.10) | libgtk-4-1, libnspr4 (>= 2:4.9-2~), libnss3 (>= 2:3.35), libpango-1.0-0 (>= 1.14.0), libudev1 (>= 183), libvulkan1, libx11-6 (>= 2:1.4.99.1), libxcb1 (>= 1.9.2), libxcomposite1 (>= 1:0.4.4-1), libxdamage1 (>= 1:1.1), libxext6, libxfixes3, libxkbcommon0 (>= 0.5.0), libxrandr2, wget, xdg-utils (>= 1.0.2)
Pre-Depends: dpkg (>= 1.14.0)
Description: The web browser from Google
 Google Chrome is a browser that combines a minimal design with sophisticated technology to make the web faster, safer, and easier.

Voici quelques-uns des commandes dpkg les plus couramment utilisées. Bien sûr, il en existe beaucoup d'autres, mais cela devrait vous donner un bon point de départ pour utiliser dpkg sur les systèmes basés sur Debian. Pour plus de détails, consultez les pages de manuel :

man dpkg

Conclusion

dpkg est un gestionnaire de paquets en ligne de commande pour gérer les logiciels sur les systèmes Linux basés sur Debian. Bien qu'il ne gère pas les dépendances, il vous aide à installer, supprimer et configurer manuellement des paquets.

Comme déjà indiqué, dpkg est un outil de niveau moyen et ne gère pas automatiquement les dépendances. Pour la résolution des dépendances, vous utilisez généralement apt ou apt-get, qui sont des interfaces de niveau supérieur à dpkg.

Lors de l'installation ou de la suppression de paquets, il est souvent préférable d'utiliser apt ou apt-get pour s'assurer que les dépendances sont correctement gérées.

Lecture liée :

  • Maîtriser les commandes APT sous Linux : un guide complet avec 15 exemples pratiques
  • Nala – Une interface en ligne de commande riche en fonctionnalités pour le gestionnaire de paquets APT